### Matplotlib rcParams for GeoSpatial Plots 
=======================

Installation
-----

```bash
pip install geoplots -U
```

Usage
-----

```python
import matplotlib.pyplot as plt
from geoplots import params

plt.rcParams.update(params)

```

License
-------

This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any means.